Index: content/common/gpu/client/gpu_memory_buffer_impl.h |
diff --git a/content/common/gpu/client/gpu_memory_buffer_impl.h b/content/common/gpu/client/gpu_memory_buffer_impl.h |
index dae9c8dc816eed3c4131a24a5b7b392920d9679b..dc792246e1fac1d29d2f02271b5dc03735b37d90 100644 |
--- a/content/common/gpu/client/gpu_memory_buffer_impl.h |
+++ b/content/common/gpu/client/gpu_memory_buffer_impl.h |
@@ -33,11 +33,9 @@ |
// Type-checking upcast routine. Returns an NULL on failure. |
static GpuMemoryBufferImpl* FromClientBuffer(ClientBuffer buffer); |
- // Calculates the number of bytes that an implementation must use to store |
- // one row of pixel data. |
- static bool StrideInBytes(size_t width, |
- Format format, |
- size_t* stride_in_bytes); |
+ // Returns the number of bytes per pixel that must be used by an |
+ // implementation when using |format|. |
+ static size_t BytesPerPixel(Format format); |
// Overridden from gfx::GpuMemoryBuffer: |
bool IsMapped() const override; |